@@ -1,6 +1,6 @@
 /*
  * JBoss, Home of Professional Open Source.
- * Copyright 2013, Red Hat, Inc., and individual contributors
+ * Copyright 2017, Red Hat, Inc., and individual contributors
  * as indicated by the @author tags. See the copyright.txt file in the
  * distribution for a full listing of individual contributors.
  *
@@ -82,11 +82,9 @@ import org.jboss.metadata.web.spec.ServletMetaData;
 import org.jboss.metadata.web.spec.ServletSecurityMetaData;
 import org.jboss.metadata.web.spec.ServletsMetaData;
 import org.jboss.metadata.web.spec.TransportGuaranteeType;
-import org.jboss.metadata.web.spec.Web30MetaData;
 import org.jboss.metadata.web.spec.WebMetaData;
 import org.jboss.modules.ModuleIdentifier;
-
-import static org.wildfly.extension.undertow.UndertowMessages.MESSAGES;
+import org.wildfly.extension.undertow.logging.UndertowLogger;
 
 /**
  * Web annotation deployment processor.
@@ -152,7 +150,7 @@ public class WarAnnotationDeploymentProcessor implements DeploymentUnitProcessor
      */
     protected WebMetaData processAnnotations(Index index)
     throws DeploymentUnitProcessingException {
-        Web30MetaData metaData = new Web30MetaData();
+        WebMetaData metaData = new WebMetaData();
         // @WebServlet
         final List<AnnotationInstance> webServletAnnotations = index.getAnnotations(webServlet);
         if (webServletAnnotations != null && webServletAnnotations.size() > 0) {
@@ -162,7 +160,7 @@ public class WarAnnotationDeploymentProcessor implements DeploymentUnitProcessor
                 ServletMetaData servlet = new ServletMetaData();
                 AnnotationTarget target = annotation.target();
                 if (!(target instanceof ClassInfo)) {
-                    throw new DeploymentUnitProcessingException(MESSAGES.invalidWebServletAnnotation(target));
+                    throw new DeploymentUnitProcessingException(UndertowLogger.ROOT_LOGGER.invalidWebServletAnnotation(target));
                 }
                 ClassInfo classInfo = ClassInfo.class.cast(target);
                 servlet.setServletClass(classInfo.toString());
@@ -173,7 +171,7 @@ public class WarAnnotationDeploymentProcessor implements DeploymentUnitProcessor
                     servlet.setName(nameValue.asString());
                 }
                 AnnotationValue loadOnStartup = annotation.value("loadOnStartup");
-                if (loadOnStartup != null && loadOnStartup.asInt() > 0) {
+                if (loadOnStartup != null && loadOnStartup.asInt() >= 0) {
                     servlet.setLoadOnStartupInt(loadOnStartup.asInt());
                 }
                 AnnotationValue asyncSupported = annotation.value("asyncSupported");
@@ -190,7 +188,7 @@ public class WarAnnotationDeploymentProcessor implements DeploymentUnitProcessor
                             AnnotationValue initParamName = initParamsAnnotation.value("name");
                             AnnotationValue initParamValue = initParamsAnnotation.value();
                             if (initParamName == null || initParamValue == null) {
-                                throw new DeploymentUnitProcessingException(MESSAGES.invalidWebInitParamAnnotation(target));
+                                throw new DeploymentUnitProcessingException(UndertowLogger.ROOT_LOGGER.invalidWebInitParamAnnotation(target));
                             }
                             AnnotationValue initParamDescription = initParamsAnnotation.value("description");
                             initParam.setParamName(initParamName.asString());
@@ -251,7 +249,7 @@ public class WarAnnotationDeploymentProcessor implements DeploymentUnitProcessor
                 FilterMetaData filter = new FilterMetaData();
                 AnnotationTarget target = annotation.target();
                 if (!(target instanceof ClassInfo)) {
-                    throw new DeploymentUnitProcessingException(MESSAGES.invalidWebFilterAnnotation(target));
+                    throw new DeploymentUnitProcessingException(UndertowLogger.ROOT_LOGGER.invalidWebFilterAnnotation(target));
                 }
                 ClassInfo classInfo = ClassInfo.class.cast(target);
                 filter.setFilterClass(classInfo.toString());
@@ -275,7 +273,7 @@ public class WarAnnotationDeploymentProcessor implements DeploymentUnitProcessor
                             AnnotationValue initParamName = initParamsAnnotation.value("name");
                             AnnotationValue initParamValue = initParamsAnnotation.value();
                             if (initParamName == null || initParamValue == null) {
-                                throw new DeploymentUnitProcessingException(MESSAGES.invalidWebInitParamAnnotation(target));
+                                throw new DeploymentUnitProcessingException(UndertowLogger.ROOT_LOGGER.invalidWebInitParamAnnotation(target));
                             }
                             AnnotationValue initParamDescription = initParamsAnnotation.value("description");
                             initParam.setParamName(initParamName.asString());
@@ -357,7 +355,7 @@ public class WarAnnotationDeploymentProcessor implements DeploymentUnitProcessor
                 ListenerMetaData listener = new ListenerMetaData();
                 AnnotationTarget target = annotation.target();
                 if (!(target instanceof ClassInfo)) {
-                    throw new DeploymentUnitProcessingException(MESSAGES.invalidWebListenerAnnotation(target));
+                    throw new DeploymentUnitProcessingException(UndertowLogger.ROOT_LOGGER.invalidWebListenerAnnotation(target));
                 }
                 ClassInfo classInfo = ClassInfo.class.cast(target);
                 listener.setListenerClass(classInfo.toString());
@@ -393,7 +391,7 @@ public class WarAnnotationDeploymentProcessor implements DeploymentUnitProcessor
                     annotations.add(annotationMD);
                 }
                 if (annotation.value() == null) {
-                    throw new DeploymentUnitProcessingException(MESSAGES.invalidRunAsAnnotation(target));
+                    throw new DeploymentUnitProcessingException(UndertowLogger.ROOT_LOGGER.invalidRunAsAnnotation(target));
                 }
                 RunAsMetaData runAs = new RunAsMetaData();
                 runAs.setRoleName(annotation.value().asString());
@@ -410,7 +408,7 @@ public class WarAnnotationDeploymentProcessor implements DeploymentUnitProcessor
             }
             for (final AnnotationInstance annotation : declareRolesAnnotations) {
                 if (annotation.value() == null) {
-                    throw new DeploymentUnitProcessingException(MESSAGES.invalidDeclareRolesAnnotation(annotation.target()));
+                    throw new DeploymentUnitProcessingException(UndertowLogger.ROOT_LOGGER.invalidDeclareRolesAnnotation(annotation.target()));
                 }
                 for (String role : annotation.value().asStringArray()) {
                     SecurityRoleMetaData sr = new SecurityRoleMetaData();
@@ -430,7 +428,7 @@ public class WarAnnotationDeploymentProcessor implements DeploymentUnitProcessor
             for (final AnnotationInstance annotation : multipartConfigAnnotations) {
                 AnnotationTarget target = annotation.target();
                 if (!(target instanceof ClassInfo)) {
-                    throw new DeploymentUnitProcessingException(MESSAGES.invalidMultipartConfigAnnotation(target));
+                    throw new DeploymentUnitProcessingException(UndertowLogger.ROOT_LOGGER.invalidMultipartConfigAnnotation(target));
                 }
                 ClassInfo classInfo = ClassInfo.class.cast(target);
                 AnnotationMetaData annotationMD = annotations.get(classInfo.toString());
@@ -470,7 +468,7 @@ public class WarAnnotationDeploymentProcessor implements DeploymentUnitProcessor
             for (final AnnotationInstance annotation : servletSecurityAnnotations) {
                 AnnotationTarget target = annotation.target();
                 if (!(target instanceof ClassInfo)) {
-                    throw new DeploymentUnitProcessingException(MESSAGES.invalidServletSecurityAnnotation(target));
+                    throw new DeploymentUnitProcessingException(UndertowLogger.ROOT_LOGGER.invalidServletSecurityAnnotation(target));
                 }
                 ClassInfo classInfo = ClassInfo.class.cast(target);
                 AnnotationMetaData annotationMD = annotations.get(classInfo.toString());
